NestedDict / ndict
==================
``NestedDict``/``ndict`` s are designed to be light-weight wrappers around existing nested dictionaries, providing additional methods for nested operations.

.. autoclass:: sndict.nesteddict.NestedDict
    :members: